import numpy as np
import scipy.stats as ss
#import matplotlib.pyplot as plt
import seaborn as sb
import stan
import pickle
import arviz as az

model_script = """
    data {
        int N;
        vector[2] XY[N];
    }
    parameters {
        real mu1;
        real mu2;
        real<lower = 0> sgm1;
        real<lower = 0> sgm2;
        real<lower=-1, upper=1> rho;
    }
    transformed parameters {
        vector[2] mus;
        matrix[2,2] cov;
        mus[1] = mu1;
        mus[2] = mu2;
        
        cov[1][1] = sgm1^2;
        cov[2][2] = sgm2^2;
        cov[1][2] = sgm1*sgm2*rho;
        cov[2][1] = cov[1][2];
    }
    model {
        mu1 ~ normal(0,10);
        mu2 ~ normal(0,10);
        sgm1 ~ exponential(0.01);
        sgm2 ~ exponential(0.01);
        rho ~ uniform(-1, 1);
        XY ~ multi_normal(mus, cov);
    }
"""

N = 5
rhos = []
for i in range(50):
    smpls = ss.multivariate_normal.rvs(mean= [0, 0],
                                       cov = [[1, 0.3], [0.3, 1]], size = N)
    Data = {'N':N, 'XY':smpls}
    sm = stan.build(model_script, data = Data)
    fit = sm.sample()
    infer_data = az.from_pystan(posterior=fit, posterior_model=sm)
    smry = az.summary(infer_data)
    print(smry)
    rhos.append(fit['rho'])

with open('fits.pkl', 'wb') as f:
    pickle.dump(rhos, f)
    
