import numpy as np
import scipy.stats as ss
import matplotlib.pyplot as plt

N = 5
tp0975 = ss.t.ppf(0.975, N-2)

def t_r(t, N):
    return ((t**2) / ((N-2) + (t**2))) ** 0.5 

r0975 = t_r(tp0975, N)

r_sample = []
for i in range(10000):
    smpls = ss.multivariate_normal.rvs(mean= [0, 0],
                                       cov = [[1, 0.3], [0.3, 1]], size = N)
    results = ss.pearsonr(smpls.T[0], smpls.T[1])
    r_sample.append(results[0])
    
plt.plot([-r0975, r0975], [0, 0], lw = 10, label = 'NonSig.Interval' +
         '\n[{0:.2f}, {1:.2f}]'.format(-r0975, r0975))
plt.hist(r_sample, bins = 20)
plt.legend(fontsize = 16)
plt.xlabel('$r$', fontsize = 20)
plt.title(r'$\rho=0.3,$' + '   ' + '$N=5$', fontsize = 20)
plt.savefig('FigSmpls.png')
plt.show()
